import numpy as np
class MyClass:
    def __init__(self, lst=[]):
        if type(lst)
        self.lst = lst.copy()
    
    def return_max(self):
        return max(self.lst)
    
    def return_min(self):
        return min(self.lst)
    
    def return_max_squared(self):
        return max(self.lst)**2
    
    def return_length(self):
        return len(self.lst)
    
    def return_positive_sum(self):
        pos_sum=0
        for e in self.lst:
            if e>0:
                pos_sum+=e
        return pos_sum
    
    def return_negative_count(self):
        neg_cnt=0
        for e in self.lst:
            if e<0:
                neg_cnt+=1
        return neg_cnt
    
    def add_element(self, e):
        self.lst.append(e)
    
    def remove_last_element(self):
        x = self.lst.pop()
        return x
    


from setuptools import setup, find_packages
import os


VERSION = '0.0.1'
DESCRIPTION = 'Homework class Rawan'

# Setting up
setup(
    name="rawan_homework",
    version=VERSION,
    author="Rawan Al-Ghamdi",
    author_email="<rawan111188@gmail.com>",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    packages=find_packages(),
    install_requires=['numpy'],
    keywords=['python', 'list', 'numbers', 'math'],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)